==> ecp_sync_plugin-6.8.6.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/volley/VolleyHelper.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.volley;


import android.content.Context;
import android.util.Log;

import com.android.volley.AuthFailureError;
import com.android.volley.DefaultRetryPolicy;
import com.android.volley.NetworkError;
import com.android.volley.NetworkResponse;
import com.android.volley.NoConnectionError;
import com.android.volley.ParseError;
import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.ServerError;
import com.android.volley.TimeoutError;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.HttpHeaderParser;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.StringRequest;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.File;
import java.io.FileInputStream;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import ecp.vcs.com.ecpsyncplugin.re_sync.interfaces.VolleyCallback;
import ecp.vcs.com.ecpsyncplugin.re_sync.logging.LogHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;


/**
 * Created by CHANDAN KUSHWAHA on 01/02/2019.
 */
public class VolleyHelper {

    private final Context context;
    private VolleyRestClient volleyRestClient;
    private VolleyCallback volleyCallback;
    private String syncType="";

    public static final int SYNC_REQUEST_CODE = 101;
    public static final int SYNC_FILE_UPLOAD_CODE = 102;

    public VolleyHelper(Context context, VolleyRestClient volleyRestClient) {
        this.context = context;
        this.volleyRestClient = volleyRestClient;
//        // Get a RequestQueue
//        RequestQueue queue = MySingleton.getInstance(context.getApplicationContext()).getRequestQueue();
    }

    public VolleyHelper(Context context, VolleyCallback volleyCallback,String syncType) {
        this.context = context;
        this.volleyCallback = volleyCallback;
        this.syncType=syncType;
    }

    /**
     * Creating a post Request
     *
     * @param url
     * @param objParam
     */
    public void postJsonRequest(String url, JSONObject objParam, long startTime, int requestCode) {

        JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, url, objParam,
                response -> volleyRestClient.onResponseSuccess(response, startTime, requestCode),
                error -> handleError(error)) {

            @Override
            protected Response<JSONObject> parseNetworkResponse(NetworkResponse response) {
                try {
                    String responseString = "";
                    if (response != null) {
                        responseString = String.valueOf(response.statusCode);
                        String responseData;
                        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.KITKAT) {
                            responseData = new String(response.data, StandardCharsets.UTF_8);
                        }else {
                            responseData = new String(response.data);
                        }
                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE:::\n" + responseData);
                        // can get more details such as response.headers
                    }
                    return Response.success(new JSONObject(responseString), HttpHeaderParser.parseCacheHeaders(response));
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                return null;
            }
        };


        //add request to queue

        jsonObjectRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
        // Add a request (in this example, called stringRequest) to your RequestQueue.
        MySingleton.getInstance(context).addToRequestQueue(jsonObjectRequest);
    }


    /**
     * Creating a post Request Using StringRequest
     *
     * @param url
     * @param objParam
     * @param startTime
     * @param requestCode
     */
    public void postStringRequest(String url, JSONObject objParam, long startTime, int requestCode) {
        StringRequest stringRequest = new StringRequest(Request.Method.POST, url, response -> {
            try {
                if (response != null) {
                    JSONObject object = new JSONObject(response);
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseSuccess(object, startTime, requestCode,syncType);
                    }else {
                        volleyRestClient.onResponseSuccess(object, startTime, requestCode);
                    }

                }
            } catch (JSONException e) {
                e.printStackTrace();
                if (syncType.trim().length()>0){
                    volleyCallback.onResponseFail(e.getMessage());
                }else {
                    volleyRestClient.onResponseFail(e.getMessage());
                }

            }
        }, error -> handleError(error)) {

            @Override
            public String getBodyContentType() {
                return "application/x-www-form-urlencoded; charset=UTF-8";
            }

            @Override
            protected Map<String, String> getParams() {
                Map<String, String> postParam = new HashMap<>();
                Iterator<String> iter = objParam.keys();
                while (iter.hasNext()) {
                    String key = iter.next();
                    try {
                        Object value = objParam.get(key);
                        postParam.put(key, (String) value);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                return postParam;
            }

            @Override
            protected Response<String> parseNetworkResponse(NetworkResponse response) {
                try {
                    if (response != null) {
                        //CheckIng Response From Server
                        String responseCode = String.valueOf(response.statusCode);
                        String responseData;
                        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.KITKAT) {
                            responseData = new String(response.data, StandardCharsets.UTF_8);
                        }else{
                            responseData = new String(response.data);
                        }
                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE CODE:: " + responseCode);
                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE" + responseData);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
                return super.parseNetworkResponse(response);

            }
        };
        stringRequest.setShouldCache(false);
        stringRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
        // Add a request (in this example, called stringRequest) to your RequestQueue.
        MySingleton.getInstance(context).addToRequestQueue(stringRequest);
    }


    /**
     * @param url         Url to Upload File
     * @param objParam    Parameter for the Upload
     * @param startTime   Upload Start Time
     * @param requestCode Unique code for Identification of Webservice
     * @Author Chandan Kushwaha
     */
    public void uploadZipFile(String url, JSONObject objParam, String fileName, long startTime, int requestCode) {
        // loading or check internet connection or something...
        // ... then
        VolleyMultipartRequest multipartRequest = new VolleyMultipartRequest(Request.Method.POST, url, response -> {
            try {
                if (response != null && response.data != null) {
                    String resultResponse = new String(response.data);
                    LogHelper.printLog("VOLLEY_TAG", resultResponse);
                    JSONObject object = new JSONObject(resultResponse);
                    volleyRestClient.onResponseSuccess(object, startTime, requestCode);
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }, error -> {
            NetworkResponse networkResponse = error.networkResponse;
            String errorMessage = "Unknown error";
            if (networkResponse == null) {
                if (error.getClass().equals(TimeoutError.class)) {
                    errorMessage = "Request timeout";
                } else if (error.getClass().equals(NoConnectionError.class)) {
                    errorMessage = "Failed to connect server";
                }
                volleyRestClient.onResponseFail(errorMessage);
            } else {
                String result = new String(networkResponse.data);
                try {
                    JSONObject response = new JSONObject(result);
                    String status = response.getString("status");
                    String message = response.getString("message");

                    Log.e("Error Status", status);
                    Log.e("Error Message", message);

                    if (networkResponse.statusCode == 404) {
                        errorMessage = "Resource not found";
                    } else if (networkResponse.statusCode == 401) {
                        errorMessage = message + " Please login again";
                    } else if (networkResponse.statusCode == 400) {
                        errorMessage = message + " Check your inputs";
                    } else if (networkResponse.statusCode == 500) {
                        errorMessage = message + " Something is getting wrong";
                    }

                    volleyRestClient.onResponseFail(errorMessage);

                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
            Log.i("Error", errorMessage);
            error.printStackTrace();
        }) {
            @Override
            protected Map<String, String> getParams() {

                Map<String, String> postParam = new HashMap<>();
                Iterator<String> iter = objParam.keys();
                while (iter.hasNext()) {
                    String key = iter.next();
                    try {
                        Object value = objParam.get(key);
                        postParam.put(key, (String) value);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                return postParam;
            }

            @Override
            protected Map<String, DataPart> getByteData() {
                Map<String, DataPart> params = new HashMap<>();
                // file name could found file base or direct access from real path
                // for now just get bitmap data from ImageView
                params.put("filename", new DataPart(fileName, getByteFromFile(fileName), "application/zip, application/octet-stream, application/x-zip-compressed, multipart/x-zip"));

                return params;
            }
        };

        multipartRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
        // Add a request (in this example, called stringRequest) to your RequestQueue.
        MySingleton.getInstance(context).addToRequestQueue(multipartRequest);
    }

    public static byte[] getByteFromFile(String filePath) {
        byte[] bytesArray = null;
        try {
            File file = new File(filePath);
            //init array with file length
            bytesArray = new byte[(int) file.length()];

            FileInputStream fis = null;

            fis = new FileInputStream(file);

            fis.read(bytesArray); //read file into bytes[]
            fis.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return bytesArray;
    }

    /**
     * Handling Volley Error
     *
     * @param error
     */
    private void handleError(VolleyError error) {
        try {
            LogHelper.printLog("VOLLEY_ERROR", "SYNC REQUEST URL::: " + error.getLocalizedMessage()+" Sync Type::"+syncType);
            LogHelper.printLog("VOLLEY_ERROR", "SYNC REQUEST URL::: " + error.getMessage()+" Sync Type::"+syncType);
            try {
                String errorData = new String(error.networkResponse.data);
                if (errorData != null && !errorData.isEmpty()) {
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseFail(errorData);
                    }else {
                        volleyRestClient.onResponseFail(errorData);
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
                if (error.getLocalizedMessage() != null && error.getLocalizedMessage().isEmpty()) {
                    if (error.getCause().getMessage().isEmpty()) {
                        if (syncType.trim().length()>0){
                            volleyCallback.onResponseFail(error.getMessage());
                        }else {
                            volleyRestClient.onResponseFail(error.getMessage());
                        }

                    } else {
                        if (syncType.trim().length()>0){
                            volleyCallback.onResponseFail(error.getMessage());
                        }else {
                            volleyRestClient.onResponseFail(error.getCause().getMessage());
                        }
                    }
                } else {
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseFail(error.getMessage());
                    }else {
                        volleyRestClient.onResponseFail(error.getLocalizedMessage());
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (error instanceof TimeoutError || error instanceof NoConnectionError) {
                volleyRestClient.onResponseFail("TimeoutError:: " + AppUtil.getStackTrace(e));
            } else if (error instanceof AuthFailureError) {
                volleyRestClient.onResponseFail("AuthFailureError:: " + AppUtil.getStackTrace(e));
            } else if (error instanceof ServerError) {
                volleyRestClient.onResponseFail("ServerError::" + AppUtil.getStackTrace(e));
            } else if (error instanceof NetworkError) {
                volleyRestClient.onResponseFail("NetworkError::" + AppUtil.getStackTrace(e));
            } else if (error instanceof ParseError) {
                volleyRestClient.onResponseFail("ParseError::" + AppUtil.getStackTrace(e));
            } else {
                volleyRestClient.onResponseFail(AppUtil.getStackTrace(e));
            }
        }

    }
}

==> ecp_sync_plugin-6.8.7.tar.gz: android/src/main/java/ecp/vcs/com/ecpsyncplugin/re_sync/volley/VolleyHelper.java <==
package ecp.vcs.com.ecpsyncplugin.re_sync.volley;


import android.content.Context;
import android.util.Log;

//import com.android.volley.AuthFailureError;
//import com.android.volley.DefaultRetryPolicy;
//import com.android.volley.NetworkError;
//import com.android.volley.NetworkResponse;
//import com.android.volley.NoConnectionError;
//import com.android.volley.ParseError;
//import com.android.volley.Request;
//import com.android.volley.Response;
//import com.android.volley.ServerError;
//import com.android.volley.TimeoutError;
//import com.android.volley.VolleyError;
//import com.android.volley.toolbox.StringRequest;

import com.android.volley.AuthFailureError;
import com.android.volley.DefaultRetryPolicy;
import com.android.volley.NetworkError;
import com.android.volley.NetworkResponse;
import com.android.volley.NoConnectionError;
import com.android.volley.ParseError;
import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.ServerError;
import com.android.volley.TimeoutError;
import com.android.volley.VolleyError;
//import com.android.volley.error.VolleyError;
import com.android.volley.toolbox.StringRequest;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.File;
import java.io.FileInputStream;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import ecp.vcs.com.ecpsyncplugin.re_sync.interfaces.VolleyCallback;
import ecp.vcs.com.ecpsyncplugin.re_sync.logging.LogHelper;
import ecp.vcs.com.ecpsyncplugin.re_sync.networking.AppUtil;


/**
 * Created by CHANDAN KUSHWAHA on 01/02/2019.
 */
public class VolleyHelper {

    private final Context context;
    private VolleyRestClient volleyRestClient;
    private VolleyCallback volleyCallback;
    private String syncType="";

    public static final int SYNC_REQUEST_CODE = 101;
    public static final int SYNC_FILE_UPLOAD_CODE = 102;

    public VolleyHelper(Context context, VolleyRestClient volleyRestClient) {
        this.context = context;
        this.volleyRestClient = volleyRestClient;
//        // Get a RequestQueue
//        RequestQueue queue = MySingleton.getInstance(context.getApplicationContext()).getRequestQueue();
    }

    public VolleyHelper(Context context, VolleyCallback volleyCallback,String syncType) {
        this.context = context;
        this.volleyCallback = volleyCallback;
        this.syncType=syncType;
    }

    /**
     * Creating a post Request
     *
     * @param url
     * @param objParam
     */
//    public void postJsonRequest(String url, JSONObject objParam, long startTime, int requestCode) {
//
//        JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, url, objParam,
//                response -> volleyRestClient.onResponseSuccess(response, startTime, requestCode),
//                this::handleError) {
//
//            @Override
//            protected Response<JSONObject> parseNetworkResponse(NetworkResponse response) {
//                try {
//                    String responseString = "";
//                    if (response != null) {
//                        responseString = String.valueOf(response.statusCode);
//                        String responseData;
//                        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.KITKAT) {
//                            responseData = new String(response.data, StandardCharsets.UTF_8);
//                        }else {
//                            responseData = new String(response.data);
//                        }
//                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE:::\n" + responseData);
//                        // can get more details such as response.headers
//                    }
//                    return Response.success(new JSONObject(responseString), HttpHeaderParser.parseCacheHeaders(response));
//                } catch (JSONException e) {
//                    e.printStackTrace();
//                }
//                return null;
//            }
//        };
//
//
//        //add request to queue
//
//        jsonObjectRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
//        // Add a request (in this example, called stringRequest) to your RequestQueue.
//        MySingleton.getInstance(context).addToRequestQueue(jsonObjectRequest);
//    }


    /**
     * Creating a post Request Using StringRequest
     *
     * @param url
     * @param objParam
     * @param startTime
     * @param requestCode
     */
    public void postStringRequest(String url, JSONObject objParam, long startTime, int requestCode) {
        StringRequest stringRequest = new StringRequest(Request.Method.POST, url, response -> {
            try {
                if (response != null) {
                    JSONObject object = new JSONObject(response);
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseSuccess(object, startTime, requestCode,syncType);
                    }else {
                        volleyRestClient.onResponseSuccess(object, startTime, requestCode);
                    }

                }
            } catch (JSONException e) {
                e.printStackTrace();
                if (syncType.trim().length()>0){
                    volleyCallback.onResponseFail(e.getMessage());
                }else {
                    volleyRestClient.onResponseFail(e.getMessage());
                }

            }
        }, null) {
//error -> handleError(error)
            @Override
            public String getBodyContentType() {
                return "application/x-www-form-urlencoded; charset=UTF-8";
            }

            @Override
            protected Map<String, String> getParams() {
                Map<String, String> postParam = new HashMap<>();
                Iterator<String> iter = objParam.keys();
                while (iter.hasNext()) {
                    String key = iter.next();
                    try {
                        Object value = objParam.get(key);
                        postParam.put(key, (String) value);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                return postParam;
            }

            @Override
            protected Response<String> parseNetworkResponse(NetworkResponse response) {
                try {
                    if (response != null) {
                        //CheckIng Response From Server
                        String responseCode = String.valueOf(response.statusCode);
                        String responseData;
                        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.KITKAT) {
                            responseData = new String(response.data, StandardCharsets.UTF_8);
                        }else{
                            responseData = new String(response.data);
                        }
                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE CODE:: " + responseCode);
                        LogHelper.printLog("VOLLEY_ERROR", "NETWORK_RESPONSE" + responseData);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
                return super.parseNetworkResponse(response);

            }
        };
        stringRequest.setShouldCache(false);
        stringRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
        // Add a request (in this example, called stringRequest) to your RequestQueue.
        MySingleton.getInstance(context).addToRequestQueue(stringRequest);
    }


    /**
     * @param url         Url to Upload File
     * @param objParam    Parameter for the Upload
     * @param startTime   Upload Start Time
     * @param requestCode Unique code for Identification of Webservice
     * @Author Chandan Kushwaha
     */
    public void uploadZipFile(String url, JSONObject objParam, String fileName, long startTime, int requestCode) {
        // loading or check internet connection or something...
        // ... then
        VolleyMultipartRequest multipartRequest = new VolleyMultipartRequest(Request.Method.POST, url, response -> {
            try {
                if (response != null && response.data != null) {
                    String resultResponse = new String(response.data);
                    LogHelper.printLog("VOLLEY_TAG", resultResponse);
                    JSONObject object = new JSONObject(resultResponse);
                    volleyRestClient.onResponseSuccess(object, startTime, requestCode);
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }, error -> {
            NetworkResponse networkResponse = error.networkResponse;
            String errorMessage = "Unknown error";
            if (networkResponse == null) {
                if (error.getClass().equals(TimeoutError.class)) {
                    errorMessage = "Request timeout";
                } else if (error.getClass().equals(NoConnectionError.class)) {
                    errorMessage = "Failed to connect server";
                }
                volleyRestClient.onResponseFail(errorMessage);
            } else {
                String result = new String(networkResponse.data);
                try {
                    JSONObject response = new JSONObject(result);
                    String status = response.getString("status");
                    String message = response.getString("message");

                    Log.e("Error Status", status);
                    Log.e("Error Message", message);

                    if (networkResponse.statusCode == 404) {
                        errorMessage = "Resource not found";
                    } else if (networkResponse.statusCode == 401) {
                        errorMessage = message + " Please login again";
                    } else if (networkResponse.statusCode == 400) {
                        errorMessage = message + " Check your inputs";
                    } else if (networkResponse.statusCode == 500) {
                        errorMessage = message + " Something is getting wrong";
                    }

                    volleyRestClient.onResponseFail(errorMessage);

                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
            Log.i("Error", errorMessage);
            error.printStackTrace();
        }) {
            @Override
            protected Map<String, String> getParams() {

                Map<String, String> postParam = new HashMap<>();
                Iterator<String> iter = objParam.keys();
                while (iter.hasNext()) {
                    String key = iter.next();
                    try {
                        Object value = objParam.get(key);
                        postParam.put(key, (String) value);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                return postParam;
            }

            @Override
            protected Map<String, DataPart> getByteData() {
                Map<String, DataPart> params = new HashMap<>();
                // file name could found file base or direct access from real path
                // for now just get bitmap data from ImageView
                params.put("filename", new DataPart(fileName, getByteFromFile(fileName), "application/zip, application/octet-stream, application/x-zip-compressed, multipart/x-zip"));

                return params;
            }
        };

        multipartRequest.setRetryPolicy(new DefaultRetryPolicy(0, 0, DefaultRetryPolicy.DEFAULT_BACKOFF_MULT));
        // Add a request (in this example, called stringRequest) to your RequestQueue.
        MySingleton.getInstance(context).addToRequestQueue(multipartRequest);
    }

    public static byte[] getByteFromFile(String filePath) {
        byte[] bytesArray = null;
        try {
            File file = new File(filePath);
            //init array with file length
            bytesArray = new byte[(int) file.length()];

            FileInputStream fis = null;

            fis = new FileInputStream(file);

            fis.read(bytesArray); //read file into bytes[]
            fis.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return bytesArray;
    }

    /**
     * Handling Volley Error
     *
     * @param error
     */
    private void handleError(VolleyError error) {
        try {
            LogHelper.printLog("VOLLEY_ERROR", "SYNC REQUEST URL::: " + error.getLocalizedMessage()+" Sync Type::"+syncType);
            LogHelper.printLog("VOLLEY_ERROR", "SYNC REQUEST URL::: " + error.getMessage()+" Sync Type::"+syncType);
            try {
                String errorData = new String(error.networkResponse.data);
                if (errorData != null && !errorData.isEmpty()) {
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseFail(errorData);
                    }else {
                        volleyRestClient.onResponseFail(errorData);
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
                if (error.getLocalizedMessage() != null && error.getLocalizedMessage().isEmpty()) {
                    if (error.getCause().getMessage().isEmpty()) {
                        if (syncType.trim().length()>0){
                            volleyCallback.onResponseFail(error.getMessage());
                        }else {
                            volleyRestClient.onResponseFail(error.getMessage());
                        }

                    } else {
                        if (syncType.trim().length()>0){
                            volleyCallback.onResponseFail(error.getMessage());
                        }else {
                            volleyRestClient.onResponseFail(error.getCause().getMessage());
                        }
                    }
                } else {
                    if (syncType.trim().length()>0){
                        volleyCallback.onResponseFail(error.getMessage());
                    }else {
                        volleyRestClient.onResponseFail(error.getLocalizedMessage());
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (error instanceof TimeoutError || error instanceof NoConnectionError) {
                volleyRestClient.onResponseFail("TimeoutError:: " + AppUtil.getStackTrace(e));
            } else if (error instanceof AuthFailureError) {
                volleyRestClient.onResponseFail("AuthFailureError:: " + AppUtil.getStackTrace(e));
            } else if (error instanceof ServerError) {
                volleyRestClient.onResponseFail("ServerError::" + AppUtil.getStackTrace(e));
            } else if (error instanceof NetworkError) {
                volleyRestClient.onResponseFail("NetworkError::" + AppUtil.getStackTrace(e));
            } else if (error instanceof ParseError) {
                volleyRestClient.onResponseFail("ParseError::" + AppUtil.getStackTrace(e));
            } else {
                volleyRestClient.onResponseFail(AppUtil.getStackTrace(e));
            }
        }

    }
}
